@@ -4,20 +4,19 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Exporter 'import';
 
 our @EXPORT = qw/return_modifiers/;
-our @EXPORT_OK =
-  qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
+our @EXPORT_OK = qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
 
 our $moo_modifiers;
 BEGIN { $moo_modifiers = [qw/has with around extends before after/] }
 
 sub return_modifiers {
     my %modifiers = ();
-    $_[1] //= $moo_modifiers;
+    $_[1] ||= $moo_modifiers; # ???
     for ( @{ $_[1] } ) {
         unless ( $modifiers{$_} = $_[0]->can($_) ) {
             croak "Can't find method <$_> in <$_[0]>";
@@ -62,7 +61,7 @@ MooX::ReturnModifiers - Returns Moo Modifiers as a Hash
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
